Group
-----

.. currentmodule:: prismstudio

.. autosummary::
    :toctree: api/

    _PrismComponent.group_rank
    _PrismComponent.group_percentile
    _PrismComponent.group_quantile
    _PrismComponent.group_z_score
    _PrismComponent.group_demean
    _PrismComponent.group_mean
    _PrismComponent.group_std
    _PrismComponent.group_skew
    _PrismComponent.group_kurt
    _PrismComponent.group_median
    _PrismComponent.group_mode
    _PrismComponent.group_sum
    _PrismComponent.group_prod
    _PrismComponent.group_count
    _PrismComponent.group_max
    _PrismComponent.group_min